]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - net.c
net.c: Rename sendall() to write_all().
[paraslash.git] / net.c
diff --git a/net.c b/net.c
index 2db340542d4f78531b6d4af4909d6fdc8eb1ce91..427ab0f0d2a3ebe3873eeff603422742b66a94b1 100644 (file)
--- a/net.c
+++ b/net.c
@@ -147,10 +147,11 @@ int makesock(unsigned l3type, unsigned l4type, int passive,
 {
        struct addrinfo *local = NULL, *src,
                        *remote = NULL, *dst, hints;
-       char            *port = make_message("%u", port_number);
        int             rc, on = 1, sockfd = -1,
                        socktype = sock_type(l4type);
+       char port[6]; /* port number has at most 5 digits */
 
+       sprintf(port, "%u", port_number);
        /* Set up address hint structure */
        memset(&hints, 0, sizeof(hints));
        hints.ai_family = l3type;
@@ -171,7 +172,7 @@ int makesock(unsigned l3type, unsigned l4type, int passive,
        if ((rc = getaddrinfo(host, port, &hints, passive ? &local : &remote))) {
                PARA_ERROR_LOG("can not resolve %s address %s#%s: %s.\n",
                                layer4_name(l4type),
-                               host?  : (passive? "[loopback]" : "[localhost]"),
+                               host? host : (passive? "[loopback]" : "[localhost]"),
                                port, gai_strerror(rc));
                return -E_ADDRESS_LOOKUP;
        }
@@ -225,7 +226,7 @@ get_next_src:
 
        if (src == NULL && dst == NULL) {
                PARA_ERROR_LOG("can not create %s socket %s#%s.\n",
-                       layer4_name(l4type), host?  : (passive?
+                       layer4_name(l4type), host? host : (passive?
                        "[loopback]" : "[localhost]"), port);
                return -ERRNO_TO_PARA_ERROR(errno);
        }
@@ -345,23 +346,23 @@ struct in_addr extract_v4_addr(const struct sockaddr_storage *ss)
 }
 
 /*
* Send out a buffer, resend on short writes.
  *
  * \param fd The file descriptor.
  * \param buf The buffer to be sent.
  * \param len The length of \a buf.
  *
- * \return Standard. In any case, the number of bytes actually sent is stored
- * in \a len.
+ * \return Standard. In any case, the number of bytes that have been written is
+ * stored in \a len.
  */
-static int sendall(int fd, const char *buf, size_t *len)
+static int write_all(int fd, const char *buf, size_t *len)
 {
        size_t total = *len;
 
        assert(total);
        *len = 0;
        while (*len < total) {
-               int ret = send(fd, buf + *len, total - *len, 0);
+               int ret = write(fd, buf + *len, total - *len);
                if (ret == -1)
                        return -ERRNO_TO_PARA_ERROR(errno);
                *len += ret;
@@ -388,7 +389,7 @@ int send_bin_buffer(int fd, const char *buf, size_t len)
        crypt_function *cf = NULL;
 
        if (!len)
-               PARA_CRIT_LOG("%s", "len == 0\n");
+               PARA_CRIT_LOG("len == 0\n");
        if (fd + 1 <= cda_size)
                cf = crypt_data_array[fd].send;
        if (cf) {
@@ -396,10 +397,10 @@ int send_bin_buffer(int fd, const char *buf, size_t len)
                /* RC4 may write more than len to the output buffer */
                unsigned char *outbuf = para_malloc(ROUND_UP(len, 8));
                (*cf)(len, (unsigned char *)buf, outbuf, private);
-               ret = sendall(fd, (char *)outbuf, &len);
+               ret = write_all(fd, (char *)outbuf, &len);
                free(outbuf);
        } else
-               ret = sendall(fd, buf, &len);
+               ret = write_all(fd, buf, &len);
        return ret;
 }
@@ -345,23 +346,23 @@ struct in_addr extract_v4_addr(const struct sockaddr_storage *ss)
 
 /*
- * Send out a buffer, resend on short writes.
+ * Write a buffer to a file descriptor, re-write on short writes.
  *
  * \param fd The file descriptor.